@@ -49,7 +49,7 @@ class StorageTests:
 
         :param collection: The name of the collection to create and use.
         """
-        raise NotImplementedError()
+        raise NotImplementedError
 
     @pytest_asyncio.fixture
     async def s(self, get_storage_args):
@@ -193,8 +193,7 @@ class StorageTests:
         )
         assert {href: etag for href, item, etag in items} == info
 
-    @pytest.mark.asyncio
-    def test_repr(self, s, get_storage_args):  # XXX: unused param
+    def test_repr(self, s):
         assert self.storage_class.__name__ in repr(s)
         assert s.instance_name is None
 
