@@ -1,19 +1,18 @@
+from __future__ import annotations
+
 import json
 import os
 import string
 from configparser import RawConfigParser
 from itertools import chain
 
-from click_threading import get_ui_worker
-
-from .. import exceptions
 from .. import PROJECT_HOME
+from .. import exceptions
 from ..utils import cached_property
 from ..utils import expand_path
 from .fetchparams import expand_fetch_params
 from .utils import storage_class_from_config
 
-
 GENERAL_ALL = frozenset(["status_path"])
 GENERAL_REQUIRED = frozenset(["status_path"])
 SECTION_NAME_CHARS = frozenset(chain(string.ascii_letters, string.digits, "_"))
@@ -89,9 +88,7 @@ def _validate_collections_param(collections):
                 raise ValueError("Duplicate value.")
             collection_names.add(collection_name)
         except ValueError as e:
-            raise ValueError(
-                "`collections` parameter, position {i}: {e}".format(i=i, e=str(e))
-            )
+            raise ValueError(f"`collections` parameter, position {i}: {str(e)}")
 
 
 class _ConfigReader:
@@ -136,7 +133,7 @@ class _ConfigReader:
                     dict(_parse_options(self._parser.items(section), section=section)),
                 )
             except ValueError as e:
-                raise exceptions.UserError('Section "{}": {}'.format(section, str(e)))
+                raise exceptions.UserError(f'Section "{section}": {str(e)}')
 
         _validate_general_section(self._general)
         if getattr(self._file, "name", None):
@@ -153,7 +150,7 @@ def _parse_options(items, section=None):
         try:
             yield key, json.loads(value)
         except ValueError as e:
-            raise ValueError('Section "{}", option "{}": {}'.format(section, key, e))
+            raise ValueError(f'Section "{section}", option "{key}": {e}')
 
 
 class Config:
@@ -191,9 +188,7 @@ class Config:
             with open(fname) as f:
                 return cls.from_fileobject(f)
         except Exception as e:
-            raise exceptions.UserError(
-                "Error during reading config {}: {}".format(fname, e)
-            )
+            raise exceptions.UserError(f"Error during reading config {fname}: {e}")
 
     def get_storage_args(self, storage_name):
         try:
@@ -208,7 +203,7 @@ class Config:
         else:
             return expand_fetch_params(args)
 
-    def get_pair(self, pair_name):
+    def get_pair(self, pair_name: str) -> PairConfig:
         try:
             return self.pairs[pair_name]
         except KeyError as e:
@@ -257,11 +252,7 @@ class PairConfig:
                 b_name = self.config_b["instance_name"]
                 command = conflict_resolution[1:]
 
-                def inner():
-                    return _resolve_conflict_via_command(a, b, command, a_name, b_name)
-
-                ui_worker = get_ui_worker()
-                return ui_worker.put(inner)
+                return _resolve_conflict_via_command(a, b, command, a_name, b_name)
 
             return resolve
         else:
@@ -324,8 +315,8 @@ load_config = Config.from_filename_or_environment
 
 
 def _resolve_conflict_via_command(a, b, command, a_name, b_name, _check_call=None):
-    import tempfile
     import shutil
+    import tempfile
 
     if _check_call is None:
         from subprocess import check_call as _check_call
